@@ -157,22 +157,20 @@ sub retrieve
   #if ( fileno (MORPHLIST)
   
   my $countinstance = 0;
-  #my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   foreach my $instance (@instances)
   {
-    #my $pid = $pm->start and next; # Begins the child process
     my %d = %{$instance};
-    my $countcase = $d{countcase}; 
-    my $countblock = $d{countblock}; 
-    my %datastruc = %{ $d{datastruc} }; ######
-      my @rescontainer = @{ $d{rescontainer} }; ######
+    my $countcase = $d{countcase}; say $tee "dump(\$countcase): " . dump($countcase);
+    my $countblock = $d{countblock}; say $tee "dump(\@countblock): " . dump(@countblock);
+    my %datastruc = %{ $d{datastruc} }; say $tee "dump(\@sweeps): " . dump(@sweeps);######
+    my @rescontainer = @{ $d{rescontainer} }; say $tee "dump(\%rescontainer): " . dump(%rescontainer);######
     my @miditers = @{ $d{miditers} }; say $tee "dump(\@miditers): " . dump(@miditers);
     my @winneritems = @{ $d{winneritems} }; say $tee  "dumpIN( \@winneritems) " . dump(@winneritems);
-    my $countvar = $d{countvar}; 
-    my $countstep = $d{countstep}; 
-    my $to = $d{to}; 
-    my $origin = $d{origin}; 
-    my @uplift = @{ $d{uplift} }; 
+    my $countvar = $d{countvar}; say $tee "dump(\$countvar): " . dump(@countvar );
+    my $countstep = $d{countstep}; say $tee "dump(\$countstep): " . dump($countstep);
+    my $to = $d{to}; say $tee "dump(\$to): " . dump($to);
+    my $origin = $d{origin}; say $tee "dump(\$origin): " . dump($origin);
+    my @uplift = @{ $d{uplift} }; say $tee "dump(\@uplift): " . dump(@uplift);
     my @backvalues = @{ $d{backvalues} }; say $tee "IN RETRIEVE \@backvalues " . dump(@backvalues);
     my @sweeps = @{ $d{sweeps} }; say $tee "dump(\@sweeps): " . dump(@sweeps);
     my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
@@ -181,32 +179,20 @@ sub retrieve
     
     my $skip = $vals{$countvar}{skip}; 
     
-    my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); 
-    my @blockelts = Sim::OPT::getblockelts(\@sweeps, $countcase, $countblock); 
-    my @blocks = Sim::OPT::getblocks(\@sweeps, $countcase);  
-    my $toitem = Sim::OPT::getitem(\@winneritems, $countcase, $countblock); 
-    my $from = Sim::OPT::getline($toitem); 
-    my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); 
-    my %mids = Sim::OPT::getcase(\@miditers, $countcase); 
-    #eval($getfly);
-    
-    my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); 
-    my $varnumber = $countvar; 
-    
-    my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); 
+    my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); say $tee "dump(\$rootname): " . dump($rootname);
+    my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say $tee "dump(\$numberof_simtools ): " . dump($numberof_simtools );
     
     my $counttool = 1;
-    while ( $counttool <= $numberof_simtools )
+    while ( $counttool <= $numberof_simtools ) 
     {  
-      my $skip = $vals{$countvar}{$counttool}{skip}; 
+      my $skip = $vals{$countvar}{$counttool}{skip}; say $tee "dump(\$skip): " . dump($skip);
       if ( not ( eval ( $skipsim{$counttool} )))
       {
-        my $tooltype = $dowhat{simtools}{$counttool}; 
+        my $tooltype = $dowhat{simtools}{$counttool}; say $tee "dump(\$tooltype ): " . dump($tooltype );
 
         sub retrieve_temperatures_results 
         {
           my ( $result, $resfile, $retrdata_ref, $reporttitle, $themereport, $counttheme, $countreport, $retfile ) = @_;
-          my @retrdata = @$retrdata_ref;
           
           
           
@@ -840,7 +826,6 @@ $printthis
         }  
       }
     }
-     #$pm->finish; # Terminates the child process
     $countinstance++;
   }
   
@@ -942,11 +927,10 @@ sub report # This function retrieves the results of interest from the texts file
   $" = " ";
   my $repfile;
   #my @convey;
-  #my $pm = new Parallel::ForkManager( $max_processes ); #Sets up the possibility of opening child processes
   my $countinstance = 0;
   foreach my $instance ( @instances )
   {
-    #my $pid = $pm->start and next; # Begins the child process
+    
     my %d = %{$instance};
     my $countcase = $d{countcase}; 
     my $countblock = $d{countblock}; 
@@ -1207,7 +1191,6 @@ sub report # This function retrieves the results of interest from the texts file
     #push ( @{ $convey[ $countcase ][ $counblock ] }, $lin );
       say "#Reporting results for case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep. Instance $countinstance: writing $repfile. ";
     }
-    #$pm->finish; # Terminates the child process
     $countinstance++;
   }
   
